Changelog
---------
1.1.2 (2019-04-23)
~~~~~~~~~~~~~~~~~~~

- Improves CSV handling.
  [msom]

1.1.1 (2019-04-23)
~~~~~~~~~~~~~~~~~~~

- Removes the YubiKey field from the login form.
  [msom]

1.1.0 (2019-04-22)
~~~~~~~~~~~~~~~~~~~

- Allows to manage admins.
  [msom]

- Makes municipality list sortable.
  [msom]

- Makes user list sortable.
  [msom]

1.0.0 (2019-04-11)
~~~~~~~~~~~~~~~~~~~

- Removes iFrame support.
  [msom]

0.0.9 (2019-04-08)
~~~~~~~~~~~~~~~~~~~

- Removes VAT from invoices.
  [msom]

0.0.8 (2019-04-02)
~~~~~~~~~~~~~~~~~~~

- Allows the application to be displayed within an iFrame.
  [msom]

0.0.7 (2019-04-01)
~~~~~~~~~~~~~~~~~~~

- Removes always run option on upgrade step.
  [msom]

0.0.6 (2019-03-29)
~~~~~~~~~~~~~~~~~~~

- Adds payment types.
  [msom]

0.0.5 (2019-03-28)
~~~~~~~~~~~~~~~~~~~

- Adds datetime picker.
  [msom]

- Directly returns the invoices CSV.
  [msom]

- Allows to create invoices for all municipalities.
  [msom]

- Colorizes the daily list boxes view.
  [msom]

0.0.4 (2019-03-13)
~~~~~~~~~~~~~~~~~~~

- Fixes municipality and users templates.
  [msom]

- Orders pickup dates when creating scan jobs as regular users.
  [msom]

- Fixes home page redirection for users without a municipality.
  [msom]

- Updates scan job labels.
  [msom]

0.0.3 (2019-03-11)
~~~~~~~~~~~~~~~~~~~

- Update deploy keys.
  [msom]

0.0.2 (2019-03-11)
~~~~~~~~~~~~~~~~~~~

- First version.
  [msom]

0.0.1 (2019-01-28)
~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [msom]
